IF OBJECT_ID('[BuildExecutions_Extended]') IS NOT NULL DROP VIEW [BuildExecutions_Extended]
GO

CREATE VIEW [BuildExecutions_Extended] AS

	SELECT BE.[Execution_Id]
		  ,A.[Application_Id]
		  ,R.[Release_Id]
		  ,R.[Release_Number]
		  ,B.[Build_Id]
		  ,B.[Build_Number]
		  ,B.[BuildStatus_Name]
		  ,R.[Pipeline_Id]
		  ,P.[Pipeline_Name]
		  ,P.[Pipeline_Color]
		  ,ENV.[Environment_Id]
		  ,ENV.[Environment_Name]
		  ,BP.[Promotion_Id]
		  ,BP.[PipelineStage_Name]
		  ,BE.[Plan_Name]
		  ,[ExecutionStart_Date] = E.[Start_Date]
		  ,[ExecutionEnded_Date] = E.[End_Date]
		  ,E.[ExecutionRunState_Code]
		  ,E.[ExecutionStatus_Code]
		  ,[ExecutionStatus_Name] =
		   CASE
				WHEN E.[ExecutionRunState_Code] = 'P' THEN 'Pending'
				WHEN E.[ExecutionRunState_Code] = 'X' AND E.[CanceledOn_Date] IS NULL THEN 'Executing'
				WHEN E.[ExecutionRunState_Code] = 'X' AND E.[CanceledOn_Date] IS NOT NULL THEN 'Canceled'
				WHEN E.[ExecutionStatus_Code] = 'E' THEN 'Failed'
				ELSE 'Succeeded'
		   END
		  ,E.[CreatedBy_User_Name]
		  ,E.[CreatedOn_Date]
		  ,E.[CanceledBy_User_Name]
		  ,E.[CanceledOn_Date]
		  ,BE.[LastActionReexecutionOf_Execution_Id]
		  ,A.[Application_Name]
		  ,BP.[PromotionStatus_Name]
		  ,BP.[Promoted_Date]
		  ,BP.[PromotedBy_Name]
		  ,[WarningLogEntry_Indicator] = CASE WHEN E.[ExecutionStatus_Code] = 'W' THEN 'Y' ELSE 'N' END
          ,[Release_Name] = COALESCE(R.[Release_Name], R.[Release_Number])
		  ,R.[ReleaseStatus_Name]
		  ,BE.[Initial_BuildExecution_DeploymentPlan_Id]
		  ,[Initial_BuildExecution_DeploymentPlan_Name] = BEDP.[Original_DeploymentPlan_Name]
		  ,A.[VariableSupport_Code]
		  ,A.[ApplicationGroup_Id]
		  ,R.[Release_Sequence]
		  ,BE.[ReexecutionState_Xml]
          ,BE.[RunContextHash_Bytes]
		  ,B.[BuildImporter_Configuration]
		  ,E.[DependentUpon_Execution_Id]
          ,BE.[PipelineStageTarget_Index]

	  FROM [BuildExecutions] BE
	       INNER JOIN [Executions] E
		          ON E.[Execution_Id] = BE.[Execution_Id]
		   INNER JOIN [BuildPromotions] BP
		           ON BP.[Promotion_Id] = BE.[Promotion_Id]
		   INNER JOIN [Builds] B
				  ON B.[Build_Id] = BP.[Build_Id]
           INNER JOIN [Releases] R
				  ON R.[Release_Id] = B.[Release_Id]
		   INNER JOIN [Applications] A
				  ON A.[Application_Id] = R.[Application_Id]
			LEFT JOIN [BuildExecution_DeploymentPlans] BEDP
			       ON BEDP.[BuildExecution_DeploymentPlan_Id] = BE.[Initial_BuildExecution_DeploymentPlan_Id]
		    LEFT JOIN [Environments] ENV
			       ON ENV.[Environment_Id] = BE.[Environment_Id]
			LEFT JOIN [Pipelines] P
				   ON P.[Pipeline_Id] = R.[Pipeline_Id]

GO
