EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'AdminEdit_UpdateBuildStatus',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates the status of a build.',
    /* Remarks_Text            */ NULL
GO

IF OBJECT_ID('[AdminEdit_UpdateBuildStatus]') IS NOT NULL DROP PROCEDURE [AdminEdit_UpdateBuildStatus]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [AdminEdit_UpdateBuildStatus]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Build_Number BUILDNUMBER,
    @BuildStatus_Name VARCHAR(8)
)
AS
BEGIN

    SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    IF EXISTS(SELECT *
	            FROM [Builds_Extended] B
               WHERE [Application_Id] = @Application_Id
                 AND [Release_Number] = @Release_Number
                 AND [Build_Number] = @Build_Number
                 AND [BuildStatus_Name] = @BuildStatus_Name)
    BEGIN
        ROLLBACK
        RETURN
    END

    IF (@BuildStatus_Name = 'Rejected')
    BEGIN

        UPDATE B
           SET B.[BuildStatus_Name] = @BuildStatus_Name,
               B.[Rejection_Notes] = 'Rejected via Administrative Edit',
               B.[RejectedBy_User_Name] = dbo.Session_GetUserName(),
               B.[Rejected_Date] = GETUTCDATE(),
               B.[ModifiedBy_User_Name] = dbo.Session_GetUserName(),
               B.[ModifiedOn_Date] = GETUTCDATE()
		  FROM [Builds] B
		       INNER JOIN [Releases] R
			           ON R.[Release_Id] = B.[Release_Id]
         WHERE R.[Application_Id] = @Application_Id
           AND R.[Release_Number] = @Release_Number
           AND B.[Build_Number] = @Build_Number

    END
    ELSE
    BEGIN

        UPDATE B
           SET B.[BuildStatus_Name] = @BuildStatus_Name,
               B.[Rejection_Notes] = NULL,
               B.[RejectedBy_User_Name] = NULL,
               B.[Rejected_Date] = NULL,
               B.[ModifiedBy_User_Name] = [dbo].Session_GetUserName(),
               B.[ModifiedOn_Date] = GETUTCDATE()
		  FROM [Builds] B
		       INNER JOIN [Releases] R
			           ON R.[Release_Id] = B.[Release_Id]
         WHERE R.[Application_Id] = @Application_Id
           AND R.[Release_Number] = @Release_Number
           AND B.[Build_Number] = @Build_Number

    END


    COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [AdminEdit_UpdateBuildStatus] TO [BuildMasterUser_Role]
