EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ApplicationGroups_CreateOrUpdateApplicationGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ApplicationGroup_Id',
    /* Description_Text        */ 'Creates or updates a new application group'
GO

IF OBJECT_ID('[ApplicationGroups_CreateOrUpdateApplicationGroup]') IS NOT NULL DROP PROCEDURE [ApplicationGroups_CreateOrUpdateApplicationGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ApplicationGroups_CreateOrUpdateApplicationGroup]
(
	@ApplicationGroup_Id INT = NULL OUT,
	@ApplicationGroup_Name VARCHAR(50),
	@ApplicationGroup_Description VARCHAR(MAX),
    @Parent_ApplicationGroup_Id INT = NULL
)
AS
BEGIN

SET NOCOUNT ON 

BEGIN TRY
	BEGIN TRANSACTION
	
	IF @ApplicationGroup_Id IS NULL
	BEGIN
		INSERT INTO [ApplicationGroups]
		(
			[ApplicationGroup_Name],
			[ApplicationGroup_Description],
			[CreatedBy_User_Name],
			[CreatedOn_Date],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date],
            [Parent_ApplicationGroup_Id]
		)
		VALUES
		(
			@ApplicationGroup_Name,
			@ApplicationGroup_Description,
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			dbo.Session_GetUserName(),
			GETUTCDATE(),
            @Parent_ApplicationGroup_Id
		)
		
		SET @ApplicationGroup_Id = SCOPE_IDENTITY()
	END
	ELSE
	BEGIN
		UPDATE [ApplicationGroups]
		   SET [ApplicationGroup_Name] = @ApplicationGroup_Name,
			   [ApplicationGroup_Description] = @ApplicationGroup_Description,
			   [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
			   [ModifiedOn_Date] = GETUTCDATE(),
               [Parent_ApplicationGroup_Id] = @Parent_ApplicationGroup_Id
		 WHERE [ApplicationGroup_Id] = @ApplicationGroup_Id
	END
	
	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ApplicationGroups_CreateOrUpdateApplicationGroup] TO [BuildMasterUser_Role]
