EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Applications_SetIssueTracker',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Sets the issue tracking provider of a specified application.'
GO

IF OBJECT_ID('[Applications_SetIssueTracker]') IS NOT NULL
	DROP PROCEDURE [Applications_SetIssueTracker]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Applications_SetIssueTracker]
(
	@Application_Id INT,
	@IssueTracking_Provider_Id INT,
	@IssueTracking_CategoryIdList_Text VARCHAR(MAX) = NULL,
	@IssueTracking_Filter_Configuration XML = NULL,
    @IssueTracking_AllowBuildMasterIssues_Indicator YNINDICATOR = NULL
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE [Applications]
	   SET [IssueTracking_Provider_Id] = @IssueTracking_Provider_Id
		  ,[IssueTracking_CategoryIdList_Text] = @IssueTracking_CategoryIdList_Text
		  ,[ModifiedBy_User_Name] = [dbo].[Session_GetUserName]()
		  ,[ModifiedOn_Date] = GETUTCDATE()
		  ,[IssueTracking_Filter_Configuration] = @IssueTracking_Filter_Configuration
          ,[IssueTracking_AllowBuildMasterIssues_Indicator] = COALESCE(@IssueTracking_AllowBuildMasterIssues_Indicator, [IssueTracking_AllowBuildMasterIssues_Indicator])
	 WHERE [Application_Id] = @Application_Id

	IF @@ROWCOUNT=0 RAISERROR('Application %i does not exist.',16,1, @Application_Id)

	/* Raise Event */
	EXEC [Events_RaiseEvent] 'APPMOD',@Application_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Applications_SetIssueTracker] TO [BuildMasterUser_Role]