EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_DeployBuild',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ '',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Marks a build and its associated release as deployed based on the settings in its workflow.'
GO

IF OBJECT_ID('[Builds_DeployBuild]') IS NOT NULL DROP PROCEDURE [Builds_DeployBuild]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_DeployBuild]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
    @Build_Number BUILDNUMBER
)
AS
BEGIN

	SET NOCOUNT ON

    BEGIN TRY
	BEGIN TRANSACTION

		DECLARE @Release_Id INT
		DECLARE @Build_Id INT
		SELECT @Release_Id = B.[Release_Id],
		       @Build_Id = B.[Build_Id]
		  FROM [Builds] B
		       INNER JOIN [Releases] R
			           ON R.[Release_Id] = B.[Release_Id]
		 WHERE R.[Application_Id] = @Application_Id
		   AND R.[Release_Number] = @Release_Number
		   AND B.[Build_Number] = @Build_Number
				

        IF (SELECT [ReleaseStatus_Name] FROM [Releases] WHERE [Application_Id] = @Application_Id AND [Release_Number] = @Release_Number) <> 'Active'
			RAISERROR('Can only deploy an active release.', 16, 1)

		IF (SELECT [BuildStatus_Name] FROM [Builds_Extended] WHERE [Application_Id] = @Application_Id AND [Release_Number] = @Release_Number AND [Build_Number] = @Build_Number) <> 'Active'
			RAISERROR('Can only deploy an active build.', 16, 1)

	    UPDATE [Releases]
		   SET [ReleaseStatus_Name] = 'Deployed'
		 WHERE [Application_Id] = @Application_Id
		   AND [Release_Number] = @Release_Number

        DECLARE @Release_Sequence BIGINT

        SELECT @Release_Sequence = [Release_Sequence]
          FROM [Releases]
         WHERE [Application_Id] = @Application_Id 
           AND [Release_Number] = @Release_Number

		UPDATE [Builds]
		   SET [BuildStatus_Name] = 'Deployed'
		 WHERE [Build_Id] = @Build_Id

		UPDATE B
		   SET B.[BuildStatus_Name] = 'Rejected',
			   B.[RejectedBy_User_Name] = dbo.Session_GetUserName(),
			   B.[Rejected_Date] = GETUTCDATE()
		  FROM [Builds] B
		       INNER JOIN [Releases] R
			           ON R.[Release_Id] = B.[Release_Id]
		 WHERE R.[Application_Id] = @Application_Id
		   AND R.[Release_Number] = @Release_Number
		   AND B.[BuildStatus_Name] = 'Active'

		INSERT INTO [ReleaseConfigurationFiles]
		(
			[Release_Id],
			[ConfigurationFile_Id],
			[Version_Number]
		)
		SELECT @Release_Id,
			   CF.[ConfigurationFile_Id],
			   CFV_Latest.[Version_Number]
		  FROM [ConfigurationFiles] CF
		       INNER JOIN [Deployables] D
			           ON D.[Deployable_Id] = CF.[Deployable_Id]
		       INNER JOIN (SELECT [ConfigurationFile_Id],
			                      [Version_Number] = MAX([Version_Number])
			                 FROM [ConfigurationFileVersions]
							GROUP BY [ConfigurationFile_Id]) CFV_Latest
					   ON CFV_Latest.[ConfigurationFile_Id] = CF.[ConfigurationFile_Id]
		 WHERE D.[Application_Id] = @Application_Id
		   AND CF.[ConfigurationFile_Id] NOT IN (SELECT [ConfigurationFile_Id]
		                                           FROM [ReleaseConfigurationFiles] RCF
												  WHERE RCF.[Release_Id] = @Release_Id)
		

	    EXEC [Events_RaiseEvent] 'RELDEP', @Application_Id, @Release_Number

	COMMIT
    END TRY BEGIN CATCH
	    IF XACT_STATE()<>0 ROLLBACK
	    EXEC [HandleError]
    END CATCH

END
GO

GRANT EXECUTE ON [Builds_DeployBuild] TO [BuildMasterUser_Role]
