EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_GetExecutionsByServer',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'BuildExecutions_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets recent build executions for the specified server.'
GO


IF OBJECT_ID('[Builds_GetExecutionsByServer]') IS NOT NULL DROP PROCEDURE [Builds_GetExecutionsByServer]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_GetExecutionsByServer]
(
	@Server_Id INT,
	@Execution_Count INT = 50
)
AS
BEGIN

	SET NOCOUNT ON

	SET @Execution_Count = COALESCE(@Execution_Count, 50)

	DECLARE @Server_Name VARCHAR(50)
	SET @Server_Name = (SELECT [Server_Name]
	                      FROM [Servers]
	                     WHERE [Server_Id] = @Server_Id)

	SELECT *
	  FROM [BuildExecutions_Extended]
	 WHERE [Execution_Id] IN
	 (
		SELECT DISTINCT TOP(@Execution_Count) BEDP.[Execution_Id]
		  FROM [BuildExecution_ActionGroupActions] BEAGA
		       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
		               ON BEDP.[BuildExecution_DeploymentPlan_Id] = BEAGA.[BuildExecution_DeploymentPlan_Id]
		 WHERE BEAGA.[Original_Server_Name] = @Server_Name
		 ORDER BY BEDP.[Execution_Id] DESC
	 )

END
GO

GRANT EXECUTE ON [Builds_GetExecutionsByServer] TO [BuildMasterUser_Role]
