EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_CreateDeploymentPlanActionGroup',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'DeploymentPlanActionGroup_Id__ActionGroup_Id',
    /* Description_Text        */ 'Creates a new action group in the specified deployment plan.'
GO


IF OBJECT_ID('[Plans_CreateDeploymentPlanActionGroup]') IS NOT NULL DROP PROCEDURE [Plans_CreateDeploymentPlanActionGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_CreateDeploymentPlanActionGroup]
(
	@DeploymentPlan_Id INT = NULL,
	@Deployable_Name VARCHAR(50) = NULL,
	@Deployable_Application_Id INT = NULL,
	@DeploymentPlanActionGroup_Sequence INT = NULL,
	@Server_Id INT = NULL,
	@Server_Variable_Name VARCHAR(50) = NULL,

	@Active_Indicator YNINDICATOR = NULL,
	@ActionGroup_Name VARCHAR(50) = NULL,
	@ActionGroup_Description VARCHAR(MAX) = NULL,
	@Predicate_Configuration XML = NULL,

	@ActionGroup_Id INT = NULL,
	@DeploymentPlanActionGroup_Id__ActionGroup_Id VARCHAR(50) = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @DeploymentPlanActionGroup_Id INT

	--If sequence is not specified, create at the end	
	IF @DeploymentPlanActionGroup_Sequence IS NULL
	BEGIN
		SET @DeploymentPlanActionGroup_Sequence = COALESCE(
			(SELECT MAX([DeploymentPlanActionGroup_Sequence])
			   FROM [DeploymentPlanActionGroups]
			  WHERE [DeploymentPlan_Id] = @DeploymentPlan_Id), 0) + 1
	END

	IF @ActionGroup_Id IS NULL
	BEGIN
		INSERT INTO [ActionGroups]
		(
			[CreatedBy_User_Name],
			[CreatedOn_Date],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date],
			[ActionGroup_Name],
			[Predicate_Configuration],
			[ActionGroup_Description],
			[Server_Id],
			[Server_Variable_Name]
		)
		VALUES
		(
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			dbo.Session_GetUserName(),
			GETUTCDATE(),
			@ActionGroup_Name,
			@Predicate_Configuration,
			@ActionGroup_Description,
			@Server_Id,
			NULLIF(@Server_Variable_Name, '')
		)

		SET @ActionGroup_Id = SCOPE_IDENTITY()

		INSERT INTO [DeploymentPlanActionGroups]
		(
			[DeploymentPlan_Id],
			[DeploymentPlanActionGroup_Sequence],
			[ActionGroup_Id],
			[Deployable_Name],
			[Deployable_Application_Id],
			[Active_Indicator],
			[ActionGroup_Name],
			[ActionGroup_Description],
			[Predicate_Configuration],
			[Server_Id],
			[Server_Variable_Name],
			[Iterate_Servers_Indicator],
			[Iterate_Deployables_Indicator],
			[Parallel_Indicator],
			[OnFailure_Continue_Indicator],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date]
		)
		VALUES
		(
			@DeploymentPlan_Id,
			@DeploymentPlanActionGroup_Sequence,
			@ActionGroup_Id,
			@Deployable_Name,
			@Deployable_Application_Id,
			COALESCE(@Active_Indicator, 'Y'),
			NULL,
			NULL,
			NULL,
			NULL,
			NULL,
			'N',
			'N',
			'N',
			'N',
			dbo.Session_GetUserName(),
			GETUTCDATE()
		)

		SET @DeploymentPlanActionGroup_Id = SCOPE_IDENTITY()
	END
	ELSE
	BEGIN
		INSERT INTO [DeploymentPlanActionGroups]
		(
			[DeploymentPlan_Id],
			[DeploymentPlanActionGroup_Sequence],
			[ActionGroup_Id],
			[Deployable_Name],
			[Deployable_Application_Id],
			[Active_Indicator],
			[ActionGroup_Name],
			[ActionGroup_Description],
			[Predicate_Configuration],
			[Server_Id],
			[Server_Variable_Name],
			[Iterate_Servers_Indicator],
			[Iterate_Deployables_Indicator],
			[Parallel_Indicator],
			[OnFailure_Continue_Indicator],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date]
		)
		VALUES
		(
			@DeploymentPlan_Id,
			@DeploymentPlanActionGroup_Sequence,
			@ActionGroup_Id,
			@Deployable_Name,
			@Deployable_Application_Id,
			@Active_Indicator,
			NULLIF(@ActionGroup_Name, ''),
			NULLIF(@ActionGroup_Description, ''),
			@Predicate_Configuration,
			@Server_Id,
			NULLIF(@Server_Variable_Name, ''),
			'N',
			'N',
			'N',
			'N',
			dbo.Session_GetUserName(),
			GETUTCDATE()
		)
		
		SET @DeploymentPlanActionGroup_Id = SCOPE_IDENTITY()
	END

	SET @DeploymentPlanActionGroup_Id__ActionGroup_Id = CAST(COALESCE(@DeploymentPlanActionGroup_Id, 0) AS VARCHAR(50)) + ':' + CAST(COALESCE(@ActionGroup_Id, 0) AS VARCHAR(50))
	
 	-- disable reexecution for anything that used the modified plan
	UPDATE [BuildExecutions]
	   SET [ReexecutionState_Xml] = NULL
	 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
	                            FROM [BuildExecution_DeploymentPlans] BEDP
	                           WHERE BEDP.[Original_DeploymentPlan_Id] = @DeploymentPlan_Id)

	EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_CreateDeploymentPlanActionGroup] TO [BuildMasterUser_Role]
