EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_UpdatePlan',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates an OtterScript deployment plan.'
GO


IF OBJECT_ID('[Plans_UpdatePlan]') IS NOT NULL DROP PROCEDURE [Plans_UpdatePlan]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_UpdatePlan]
(
	@Plan_Id INT,
    @Plan_Name VARCHAR(255),
    @Plan_Bytes VARBINARY(MAX),
    @Environment_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    DECLARE @NextPlanVersion_Id INT

    SELECT @NextPlanVersion_Id = COALESCE(MAX([PlanVersion_Id]), 0) + 1 
      FROM [PlanVersions]
     WHERE [Plan_Id] = @Plan_Id


	UPDATE [Plans]
       SET [Plan_Name] = @Plan_Name,
           [ModifiedOn_Date] = GETUTCDATE(),
           [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
           [Environment_Id] = @Environment_Id
     WHERE [Plan_Id] = @Plan_Id

     INSERT INTO [PlanVersions] ([PlanVersion_Id], [Plan_Id], [ModifiedOn_Date], [ModifiedBy_User_Name], [Plan_Bytes])
        VALUES (@NextPlanVersion_Id, @Plan_Id, GETUTCDATE(), dbo.Session_GetUserName(), @Plan_Bytes)

	EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @Plan_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_UpdatePlan] TO [BuildMasterUser_Role]
