EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Scripts_CreateOrUpdateParameter',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new script parameter or updates an existing one.'
GO


IF OBJECT_ID('[Scripts_CreateOrUpdateParameter]') IS NOT NULL DROP PROCEDURE [Scripts_CreateOrUpdateParameter]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Scripts_CreateOrUpdateParameter]
(
	@Script_Id INT,
	@Parameter_Name NVARCHAR(50),
	@ParameterType_Code CHAR(1),
	@DefaultValue_Text NVARCHAR(MAX),
	@Description_Text NVARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
	            FROM [ScriptParameters]
	           WHERE [Script_Id] = @Script_Id
	             AND [Parameter_Name] = @Parameter_Name)
	BEGIN

		UPDATE [ScriptParameters]
		   SET [ParameterType_Code] = @ParameterType_Code,
		       [DefaultValue_Text] = @DefaultValue_Text,
		       [Description_Text] = @Description_Text
		 WHERE [Script_Id] = @Script_Id
		   AND [Parameter_Name] = @Parameter_Name

	END
	ELSE
	BEGIN

		INSERT INTO [ScriptParameters]
		(
			[Script_Id],
			[Parameter_Name],
			[ParameterType_Code],
			[DefaultValue_Text],
			[Description_Text]
		)
		VALUES
		(
			@Script_Id,
			@Parameter_Name,
			@ParameterType_Code,
			@DefaultValue_Text,
			@Description_Text
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Scripts_CreateOrUpdateParameter] TO [BuildMasterUser_Role]