EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Scripts_CreateOrUpdateVariable',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new script variable or updates an existing one.'
GO


IF OBJECT_ID('[Scripts_CreateOrUpdateVariable]') IS NOT NULL DROP PROCEDURE [Scripts_CreateOrUpdateVariable]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Scripts_CreateOrUpdateVariable]
(
	@Script_Id INT,
	@ScriptVariable_Name NVARCHAR(50),
	@Value_Text NVARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
	            FROM [ScriptVariables]
	           WHERE [Script_Id] = @Script_Id
	             AND [ScriptVariable_Name] = @ScriptVariable_Name)
	BEGIN

		UPDATE [ScriptVariables]
		   SET [Value_Text] = @Value_Text
		 WHERE [Script_Id] = @Script_Id
		   AND [ScriptVariable_Name] = @ScriptVariable_Name

	END
	ELSE
	BEGIN

		INSERT INTO [ScriptVariables]
		(
			[Script_Id],
			[ScriptVariable_Name],
			[Value_Text]
		)
		VALUES
		(
			@Script_Id,
			@ScriptVariable_Name,
			@Value_Text
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Scripts_CreateOrUpdateVariable] TO [BuildMasterUser_Role]