EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'TextTemplates_CreateOrUpdateTemplate',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'TextTemplate_Id',
    /* Description_Text        */ 'Creates a new text template or updates an existing one.'
GO

IF OBJECT_ID('[TextTemplates_CreateOrUpdateTemplate]') IS NOT NULL DROP PROCEDURE [TextTemplates_CreateOrUpdateTemplate]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [TextTemplates_CreateOrUpdateTemplate]
(
	@Template_Name VARCHAR(200),
	@Application_Id INT,
	@Template_Bytes VARBINARY(MAX),
	@TextTemplate_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @TextTemplate_Id IS NULL
	BEGIN

		INSERT INTO [TextTemplates]
		(
			[Template_Name],
			[Application_Id],
			[Template_Bytes]
		)
		VALUES
		(
			@Template_Name,
			@Application_Id,
            @Template_Bytes
		)

		SET @TextTemplate_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [TextTemplates]
		   SET [Template_Name] = @Template_Name,
			   [Application_Id] = @Application_Id,
			   [Template_Bytes] = @Template_Bytes
		 WHERE [TextTemplate_Id] = @TextTemplate_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [TextTemplates_CreateOrUpdateTemplate] TO [BuildMasterUser_Role]