EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Variables_CreateDeploymentVariable',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a deployment variable.'
GO

IF OBJECT_ID('[Variables_CreateDeploymentVariable]') IS NOT NULL DROP PROCEDURE [Variables_CreateDeploymentVariable]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Variables_CreateDeploymentVariable]
(
    @Execution_Id INT,
	@Variable_Name VARCHAR(50),
	@ValueType_Code CHAR(1),
	@Variable_Value VARBINARY(MAX),
    @Sensitive_Indicator YNINDICATOR,
    @EvaluateVariables_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT *
	            FROM [DeploymentVariables]
			   WHERE [Execution_Id] = @Execution_Id
                 AND [Variable_Name] = @Variable_Name)
	BEGIN

		UPDATE [DeploymentVariables]
		   SET [ValueType_Code] = @ValueType_Code,
		       [Variable_Value] = @Variable_Value,
               [Sensitive_Indicator] = @Sensitive_Indicator,
               [EvaluateVariables_Indicator] = @EvaluateVariables_Indicator
		 WHERE [Execution_Id] = @Execution_Id
           AND [Variable_Name] = @Variable_Name

	END
	ELSE
	BEGIN

		INSERT INTO [DeploymentVariables]
		(
			[Execution_Id],
            [Variable_Name],
            [ValueType_Code],
			[Variable_Value],
            [Sensitive_Indicator],
            [EvaluateVariables_Indicator]
		)
		VALUES
		(
            @Execution_Id,
            @Variable_Name,
            @ValueType_Code,
            @Variable_Value,
            @Sensitive_Indicator,
            @EvaluateVariables_Indicator
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Variables_CreateDeploymentVariable] TO [BuildMasterUser_Role]
